"""
expscipy

An enhanced version of scipy with additional features and improvements.
"""

from .version import __version__

# Import core components
# Replace with actual imports for your enhanced library
from .core import *

# Add any additional imports specific to your enhanced library
# from .extensions import *

__all__ = [
    '__version__',
    # Add all public API elements here
]



"""
Version information.
"""

__version__ = '0.1.0'
__author__ = 'Sumedh Patil'
__author_email__ = 'sumedh@aipresso.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2025 Sumedh Patil, Aipresso Limited, UK'



"""
Core functionality for expscipy.

This module contains the core functionality that enhances the original scipy.
"""

# Import original library components that we're enhancing
# import scipy as _original

# Define enhanced versions of the original components
# class EnhancedComponent:
#     """Enhanced version of original component with additional functionality."""
#     
#     def __init__(self, *args, **kwargs):
#         """Initialize the enhanced component."""
#         self._original = _original.Component(*args, **kwargs)
#         
#     def original_method(self, *args, **kwargs):
#         """Call the original method."""
#         return self._original.method(*args, **kwargs)
#         
#     def enhanced_method(self, *args, **kwargs):
#         """New method that enhances the original functionality."""
#         # Implementation here
#         pass



import os
from setuptools import setup, find_packages

# Read the contents of your README file
with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

# Read version from version.py
about = {}
with open(os.path.join('src', 'expscipy', 'version.py'), 'r', encoding='utf-8') as f:
    exec(f.read(), about)

setup(
    name='expscipy',
    version=about['__version__'],
    author='Sumedh Patil',
    author_email='sumedh@aipresso.com',
    description='Enhanced version of SciPy with additional scientific computing features',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/Sumedh1599/expscipy',
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
    python_requires='>=3.7',
    install_requires=[
        'scipy>=1.0.0',
        'numpy>=1.20.0',
        'scipy>=1.7.0'
    ],
    extras_require={
        'dev': [
            'pytest>=7.0.0',
            'pytest-cov>=4.0.0',
            'black>=23.0.0',
            'isort>=5.0.0',
            'sphinx>=5.0.0',
            'sphinx-rtd-theme>=1.0.0',
        ],
    },
    project_urls={
        'Bug Reports': 'https://github.com/Sumedh1599/expscipy/issues',
        'Source': 'https://github.com/Sumedh1599/expscipy',
        'Documentation': 'https://expscipy.readthedocs.io/',
    },
)
